/*****************************************************************************
 * Copyright © 2012 - 2013, M2X BV
 * Author: Jean-Paul Saman
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 ****************************************************************************/

#ifndef VLC_VAAPI_SPU_H
#define VLC_VAAPI_SPU_H 1

/* Available subtitle formats */
static const vlc_fourcc_t va_subpicture_chromas[] = {
    VLC_CODEC_RGBA,
    0
};

/* Check if subtitle format is supported by VA API */
int VASubtitleFourCC(vlc_va_conn_t *va, const unsigned int vafourcc, VAImageFormat *sub_fmt, int *flags);

/* */
typedef struct vlc_va_spu_cache_t vlc_va_spu_cache_t;
typedef struct spu_cache_t  spu_cache_t;

/* Get Cache id */
unsigned int vlc_va_spu_cache_GetID(const spu_cache_t *cache);

/* Empty the array of cached subpictures */
vlc_va_spu_cache_t *vlc_va_spu_cache_New(void);
void vlc_va_spu_cache_Delete(vlc_va_conn_t *va, vlc_va_spu_cache_t *restrict spu);

/* Hold and Release reference to subpicture cache object */
void vlc_va_spu_cache_Hold(vlc_va_spu_cache_t *spu, const int cache_id);
void vlc_va_spu_cache_Release(vlc_va_conn_t *va, vlc_va_spu_cache_t *spu, const int cache_id);

/* Link/Unlink VASubpicture to/from VASurface */
int vlc_va_spu_cache_Link(vlc_object_t *obj, vlc_va_conn_t *va, vlc_va_spu_cache_t *spu,
                          const picture_t *picture, const int flags);
int vlc_va_spu_cache_Unlink(vlc_object_t *obj, vlc_va_conn_t *va, vlc_va_spu_cache_t *spu,
                            const picture_t *picture);

/* Create VLC subpictures as VASubpictures and put them into a subpicture cache */
spu_cache_t *vlc_va_spu_cache_Prepare(vlc_object_t *obj, vlc_va_conn_t *va, VAImageFormat *fmt,
                                      picture_t *picture, subpicture_t *subpicture, int flags);

/* Check if cached subpicture can be reused for the next Subpicture Render cycle */
int vlc_va_spu_cache_Get(vlc_object_t *obj, vlc_va_spu_cache_t *spu, const unsigned int cache_id,
                         picture_t *picture, subpicture_t *subpicture);
void vlc_va_spu_cache_Put(vlc_va_spu_cache_t *spu, spu_cache_t *cache);

#endif
